==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property excludedCookies
 * @property includedCookies
 */
public data class
WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs(
    public val all:
    Output<WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null,
    public val excludedCookies: Output<List<String>>? = null,
    public val includedCookies: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs> {
    override fun toJava():
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs.builder()
            .all(all?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .excludedCookies(excludedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .includedCookies(includedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs].
 */
@PulumiTagMarker
public class
WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgsBuilder
internal constructor() {
    private var all:
        Output<WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null

    private var excludedCookies: Output<List<String>>? = null

    private var includedCookies: Output<List<String>>? = null

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("wcwniltixafmjhpr")
    public suspend
    fun all(`value`: Output<WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs>) {
        this.all = value
    }

    /**
     * @param value
     */
    @JvmName("hmsegopmpwabjrqn")
    public suspend fun excludedCookies(`value`: Output<List<String>>) {
        this.excludedCookies = value
    }

    @JvmName("dcfnyqddbyqfnbwm")
    public suspend fun excludedCookies(vararg values: Output<String>) {
        this.excludedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("mngolubjtbmvvgmx")
    public suspend fun excludedCookies(values: List<Output<String>>) {
        this.excludedCookies = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("hxfawmyjagumnpyq")
    public suspend fun includedCookies(`value`: Output<List<String>>) {
        this.includedCookies = value
    }

    @JvmName("brvagoolwswiwmuf")
    public suspend fun includedCookies(vararg values: Output<String>) {
        this.includedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("kmcjltexgbeisjmq")
    public suspend fun includedCookies(values: List<Output<String>>) {
        this.includedCookies = Output.all(values)
    }

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("afmpteaxyurxcrtd")
    public suspend
    fun all(`value`: WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.all = mapped
    }

    /**
     * @param argument An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("vtmkmqnncxwhtbcs")
    public suspend
    fun all(argument: suspend WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgsBuilder.() -> Unit) {
        val toBeMapped =
            WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.all = mapped
    }

    /**
     * @param value
     */
    @JvmName("jpmkaclvmqcnidpn")
    public suspend fun excludedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("kqspksbrxgnyhrqr")
    public suspend fun excludedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param value
     */
    @JvmName("exfabcsrekwedqks")
    public suspend fun includedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("brlkapdhuppxdvdk")
    public suspend fun includedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    internal fun build():
        WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs =
        WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs(
            all = all,
            excludedCookies = excludedCookies,
            includedCookies = includedCookies,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property excludedCookies
 * @property includedCookies
 */
public data class
WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs(
    public val all: Output<WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null,
    public val excludedCookies: Output<List<String>>? = null,
    public val includedCookies: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs.builder()
            .all(all?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .excludedCookies(excludedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .includedCookies(includedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs].
 */
@PulumiTagMarker
public class
WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgsBuilder
internal constructor() {
    private var all:
        Output<WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null

    private var excludedCookies: Output<List<String>>? = null

    private var includedCookies: Output<List<String>>? = null

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("kwcmhhwinrgpyhlw")
    public suspend fun all(`value`: Output<WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs>) {
        this.all = value
    }

    /**
     * @param value
     */
    @JvmName("ioqvtxltjwjfvgpx")
    public suspend fun excludedCookies(`value`: Output<List<String>>) {
        this.excludedCookies = value
    }

    @JvmName("ofsdtecjqxdhlwom")
    public suspend fun excludedCookies(vararg values: Output<String>) {
        this.excludedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("aakcligbkxksaldr")
    public suspend fun excludedCookies(values: List<Output<String>>) {
        this.excludedCookies = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("atqpydahysxxselp")
    public suspend fun includedCookies(`value`: Output<List<String>>) {
        this.includedCookies = value
    }

    @JvmName("gsogeoscwhninmvb")
    public suspend fun includedCookies(vararg values: Output<String>) {
        this.includedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("drdfnvxcxrxahuca")
    public suspend fun includedCookies(values: List<Output<String>>) {
        this.includedCookies = Output.all(values)
    }

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("dacvhesbfvnewssh")
    public suspend fun all(`value`: WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.all = mapped
    }

    /**
     * @param argument An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("qunwbfwnjoenvuuh")
    public suspend fun all(argument: suspend WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgsBuilder.() -> Unit) {
        val toBeMapped =
            WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.all = mapped
    }

    /**
     * @param value
     */
    @JvmName("mgnivdgctkbggnwo")
    public suspend fun excludedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("xpusvbagjjgaqxwh")
    public suspend fun excludedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param value
     */
    @JvmName("vadkibqgmacwoagh")
    public suspend fun includedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("urkdgnfeitamvcgh")
    public suspend fun includedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    internal fun build(): WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs =
        WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs(
            all = all,
            excludedCookies = excludedCookies,
            includedCookies = includedCookies,
        )
}
